;; Generated package description from diff-ansi.el  -*- mode: lisp-data; no-byte-compile: t; lexical-binding:t -*-
(define-package "diff-ansi" "0.2.0.20260524.93804" "Display diffs using alternative diffing tools" '((emacs "29.1")) :commit "2edacc2c6bda60b1be7bf5dfdde006a9a7018af5" :authors '(("Campbell Barton" . "ideasman42@gmail.com")) :maintainer '("Campbell Barton" . "ideasman42@gmail.com") :url "https://codeberg.org/ideasman42/emacs-diff-ansi")
